;;; jman.el --- browse UNIX Japanese manual pages
;;; $Id: jman.el,v 1.1 1997/03/30 02:57:18 max Exp $

;;;  This file part of jman-1.1 - japanese man with EUC, 
;;;  a GNU Emacs front end to the UNIX Japanese manual pages browsing.

;;; Everyone is granted permission to copy, modify and redistribute
;;; this program.

;;; HISTORY
;;;
;;;	Written by Mitsuru IWASAKI 1 March, 1997
;;;		jman, i18n-man, man (re-definition), 
;;;		and some user variables for i18ned manual pages.
;;;

;;; Suggested USAGE
;;;
;;;  In your ~/.emacs
;;;(autoload 'jman "jman" nil t)
;;;  then
;;;  M-x jman
;;;    to get a Japanese manual page thru jman(1) and put it in a buffer.
;;;
;;;  M-x man
;;;    to get an original manual page thru man(1) and put it in a buffer.
;;;

(require 'man)

;; vvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvv
;; user variables

(defvar i18n-manual-program "jman"
  "The name of the i18ned program that produces man pages.")

(defvar i18n-Man-heading-regexp "^\\([^ \t\n_][^0-9\n]+\\)$"
  "*Regular expression describing a i18ned manpage heading entry.")

(defvar i18n-Man-see-also-regexp "Ϣ\\|SEE ALSO"
  "*Regular expression for SEE ALSO heading (or your equivalent) of a i18ned mangage.
This regexp should not start with a `^' character.")

(defvar i18n-Man-first-heading-regexp "^[ \t]*̾$\\|^[ \t]*NAME$\\|^[ \t]*No manual entry fo.*"
  "*Regular expression describing first heading on a i18ned manpage.
This regular expression should start with a `^' character.")

;; ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;; end user variables

;; ======================================================================
;; top level command and background process sentinel

;;; This alias makes completion more predictable if ignoring case.
;;;###autoload
(defalias 'jman 'i18n-man)

;; back some variables up
(setq manual-program-orig manual-program)
(setq Man-heading-regexp-orig Man-heading-regexp)
(setq Man-see-also-regexp-orig Man-see-also-regexp)
(setq Man-first-heading-regexp-orig Man-first-heading-regexp)

(defun i18n-man (arg)
  nil
  (interactive "P")
  (setq manual-program i18n-manual-program)
  (setq Man-heading-regexp i18n-Man-heading-regexp)
  (setq Man-see-also-regexp i18n-Man-see-also-regexp)
  (setq Man-first-heading-regexp i18n-Man-first-heading-regexp)
  (manual-entry arg))

;;;###autoload
(defun man (arg)
  nil
  (interactive "P")
  (setq manual-program manual-program-orig)
  (setq Man-heading-regexp Man-heading-regexp-orig)
  (setq Man-see-also-regexp Man-see-also-regexp-orig)
  (setq Man-first-heading-regexp Man-first-heading-regexp-orig)
  (manual-entry arg))


(provide 'jman)

;;; jman.el ends here
